# Sqller

ORM library to build SQLite based application in format model/dao/service.

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes. See deployment for notes on how to deploy the project on a live system.

## Installing

At first, you need SQLite3 to be installed. Type following in your terminal:

```bash
apt-get install libsqlite3-dev
```

To install the package type the following in your terminal:

```bash
sudo pip install sqller
```

## Running the tests

To run tests type the following in your terminal:

```bash
python3 -m pytest
```

or

```bash
python -m pytest
```

if the previous command doesn't work.

## Contributing

Please read [CONTRIBUTING.md](https://gist.github.com/PurpleBooth/b24679402957c63ec426) for details on our code of conduct, and the process for submitting pull requests to us.

## Versioning

We use [SemVer](http://semver.org/) for versioning. For the versions available, see the [tags on this repository](https://github.com/your/project/tags).

## Authors

- **Ilya Vouk** - Initial work - [VoIlAlex](https://github.com/VoIlAlex)

See also the list of [contributors](https://github.com/VoIlAlex/sqller/contributors) who participated in this project.

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details
